${ title }

<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="title_head"> <%block name="extra_meta"> ${ setup_margin_labels(title) }
${ header(complete_header, title, report.subtitle, notes) }

${ _("Equipment") }: | ${ report.workorder.equipment }
${ _("Client") }: | ${ report.workorder.client.person.name } | ${ _("Responsible") }: | ${ report.workorder.execution_responsible.get_description() if \ report.workorder.execution_responsible else '' }
${ _("Approval date") }: | ${ format_date(report.workorder.approve_date) } | ${ _("Finish date") }: | ${ format_date(report.workorder.finish_date) }

${ _("Code") } | ${ _("Item") } | ${ _("Quantity") } | ${ _("Price") } | ${ _("Total") }
% for item in report.workorder.order_items:
${ item.sellable.code } | ${ item.sellable.get_description() } | ${ format_quantity(item.quantity) } | ${ format_price(item.price) } | ${ format_price(item.total) }
% endfor
${ _("Total") }: | ${ format_price(report.workorder.get_total_amount()) }

${ report.workorder.client.get_description() }